@@ -274,5 +274,5 @@ class Service:
             self.scheduler_period = msg['scheduler_period']
             self.dingtalk_function = msg['ding_talk_function']
             self.restart_flag = msg['restart_flag']
-            self.restart_name = msg['restart_name']
-            self.args = msg['args']
+            self.restart_name = msg.get('restart_name', 0)
+            self.args = msg.get('args', None)
